How we made editing Wikipedia twice as fast
Over the past six months we deployed a new technology that sped up Wikipedia’s backend application, reducing the median page-saving time for editors from about 7.5 seconds to 2.5 seconds.
The latest blog posts to take off on Hacker News. 110 posts.
Over the past six months we deployed a new technology that sped up Wikipedia’s backend application, reducing the median page-saving time for editors from about 7.5 seconds to 2.5 seconds.
While JavaScript employs garbage collection for automatic memory management, it is not a substitute for effective memory management in applications. JavaScript applications suffer from the same memory related problems that native applications do, such as memory leaks and bloat, yet they must also deal with garbage…
Find software and development products, explore tools and technologies, connect with other developers and more. Sign up to manage your products.
Posted by Ian BeerTL;DRAn OS X GPU driver trusted a user-supplied kernel C++ object pointer and c...
Visit the post for more.
This post is by Konstantin Lopuhin, who tried PyPy STM during the Warsaw sprint. Python has a GIL, right? Not quite - PyPy STM is a python ...
Simon Peter, Jialin Li, Irene Zhang, Dan R. K. Ports, Doug Woos, Arvind Krishnamurthy, and Thomas Anderson, University of Washington; Timothy Roscoe, ETH Zürich
Earlier this year I wrote about container computing and enumerated some of the benefits that you get when you use it as the basis for a distributed application platform: consistency & fidelity, development efficiency, and operational efficiency. Because containers are lighter in weight and have less memory and…
Discover Azure Kubernetes Service (AKS) for secure, scalable containerized app deployment and management with fast delivery on managed Kubernetes clusters.
Ruby web server up to 4x faster than Unicorn, up to 2x faster than Puma and Torquebox.
Hello everyone! We've wrapped up the Warsaw sprint, so I would like to describe some branches which have been recently merged and which i...
If you record every heap allocation and re-allocation done by Firefox you find some interesting things. In particular, you find some sub-optimal buffer growth strategies that cause a lot of heap churn.